%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 Xeda Documentation Contents
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



**Xeda** `/ˈziːdə/` is a cross-platform, cross-EDA, cross-target automated synthesis and simulation platform.
It helps hardware developers to verify, evaluate, and deploy their RTL designs using multiple commercial and open-source electronic design automation flows.


.. toctree::
   tutorial/index.rst

   about.rst
   quickstart.rst
   flows.rst
   bugs.rst
   copyright.rst
   license.rst